#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

GOM(XGetXCBConnection, pFEp)
GO(XSetEventQueueOwner, vFpu)
